# BCOLORS

Setting Text ForeGround Color. This can be used with Print Statement.

## Installation

```bash
pip install bcolors
```

## Usage

```python
import bcolors as b
print(b.OK + "Color Statement" + b.END)
```
